@@ -218,7 +218,9 @@ e_mail_parser_base_init (EMailParserClass *class)
 
 	/* Register internal extensions. */
 	g_type_ensure (e_mail_parser_application_mbox_get_type ());
-	g_type_ensure (e_mail_parser_audio_get_type ());
+	/* This is currently disabled, because the WebKit player requires javascript,
+	   which is disabled in Evolution. */
+	/* g_type_ensure (e_mail_parser_audio_get_type ()); */
 	g_type_ensure (e_mail_parser_headers_get_type ());
 	g_type_ensure (e_mail_parser_message_get_type ());
 	g_type_ensure (e_mail_parser_secure_button_get_type ());
