@@ -20,10 +20,7 @@
 
 #include <string.h>
 
-#define WEBKIT_DOM_USE_UNSTABLE_API
-#include <webkitdom/WebKitDOMDOMSelection.h>
-#include <webkitdom/WebKitDOMDOMWindowUnstable.h>
-#include <webkitdom/WebKitDOMHTMLElementUnstable.h>
+#include <webkitdom/webkitdom.h>
 
 #include "e-web-extension.h"
 #include "e-web-extension-names.h"
@@ -798,6 +795,10 @@ e_dom_utils_bind_dom (WebKitDOMDocument *document,
 		WebKitDOMNode *node;
 
 		node = webkit_dom_node_list_item (nodes, ii);
+		webkit_dom_event_target_remove_event_listener (
+			WEBKIT_DOM_EVENT_TARGET (node), event,
+			G_CALLBACK (callback), FALSE);
+
 		webkit_dom_event_target_add_event_listener (
 			WEBKIT_DOM_EVENT_TARGET (node), event,
 			G_CALLBACK (callback), FALSE, user_data);
@@ -1027,6 +1028,10 @@ e_dom_utils_e_mail_display_bind_dom (WebKitDOMDocument *document,
 
 	dom_window = webkit_dom_document_get_default_view (document);
 
+	webkit_dom_event_target_remove_event_listener (
+		WEBKIT_DOM_EVENT_TARGET (dom_window), "resize",
+		G_CALLBACK (dom_window_resize_cb), FALSE);
+
 	webkit_dom_event_target_add_event_listener (
 		WEBKIT_DOM_EVENT_TARGET (dom_window),
 		"resize",
@@ -1043,6 +1048,58 @@ e_dom_utils_e_mail_display_bind_dom (WebKitDOMDocument *document,
 	e_dom_resize_document_content_to_preview_width (document);
 }
 
+void
+e_dom_utils_e_mail_display_unstyle_blockquotes (WebKitDOMDocument *document)
+{
+	WebKitDOMHTMLCollection *collection;
+	gulong ii;
+
+	g_return_if_fail (WEBKIT_DOM_IS_DOCUMENT (document));
+
+	collection = webkit_dom_document_get_elements_by_tag_name_as_html_collection (document, "blockquote");
+	for (ii = webkit_dom_html_collection_get_length (collection); ii--;) {
+		WebKitDOMNode *node = webkit_dom_html_collection_item (collection, ii);
+		WebKitDOMElement *elem;
+		gchar *tmp;
+
+		if (!WEBKIT_DOM_IS_HTML_QUOTE_ELEMENT (node))
+			continue;
+
+		elem = WEBKIT_DOM_ELEMENT (node);
+
+		if (!webkit_dom_element_has_attribute (elem, "type")) {
+			webkit_dom_element_set_attribute (elem, "type", "cite", NULL);
+			webkit_dom_element_remove_attribute (elem, "style");
+		} else {
+			tmp = webkit_dom_element_get_attribute (elem, "type");
+			if (g_strcmp0 (tmp, "cite") == 0)
+				webkit_dom_element_remove_attribute (elem, "style");
+			g_free (tmp);
+		}
+
+		tmp = webkit_dom_element_get_attribute (elem, "style");
+		if (g_strcmp0 (tmp, E_EVOLUTION_BLOCKQUOTE_STYLE) == 0)
+			webkit_dom_element_remove_attribute (elem, "style");
+		g_free (tmp);
+	}
+	g_clear_object (&collection);
+
+	collection = webkit_dom_document_get_elements_by_tag_name_as_html_collection (document, "iframe");
+	for (ii = webkit_dom_html_collection_get_length (collection); ii--;) {
+		WebKitDOMHTMLIFrameElement *iframe;
+		WebKitDOMDocument *content_document;
+
+		iframe = WEBKIT_DOM_HTML_IFRAME_ELEMENT (webkit_dom_html_collection_item (collection, ii));
+
+		content_document = webkit_dom_html_iframe_element_get_content_document (iframe);
+		if (!content_document)
+			continue;
+
+		e_dom_utils_e_mail_display_unstyle_blockquotes (content_document);
+	}
+	g_clear_object (&collection);
+}
+
 void
 e_dom_utils_eab_contact_formatter_bind_dom (WebKitDOMDocument *document)
 {
